.. list-table:: Provider Compatibility Matrix
   :header-rows: 1
   :widths: 20 12 12 12 12 12 20

   * - Provider
     - JSON Mode
     - JSON Schema
     - Tool Use
     - Streaming
     - Vision
     - Best Strategy
   * - ``airllm``
     - No
     - No
     - No
     - No
     - No
     - ``prompted_repair``
   * - ``azure``
     - Yes
     - Yes
     - Yes
     - No
     - Yes
     - ``provider_native``
   * - ``cachibot``
     - Yes
     - No
     - Yes
     - Yes
     - Yes
     - ``provider_native``
   * - ``claude``
     - Yes
     - Yes
     - Yes
     - Yes
     - Yes
     - ``provider_native``
   * - ``google``
     - Yes
     - Yes
     - Yes
     - Yes
     - Yes
     - ``provider_native``
   * - ``grok``
     - Yes
     - No
     - Yes
     - No
     - Yes
     - ``provider_native``
   * - ``groq``
     - Yes
     - No
     - Yes
     - No
     - Yes
     - ``provider_native``
   * - ``huggingface``
     - No
     - No
     - No
     - No
     - No
     - ``prompted_repair``
   * - ``lmstudio``
     - Yes
     - Yes
     - No
     - No
     - Yes
     - ``provider_native``
   * - ``local_http``
     - No
     - No
     - No
     - No
     - No
     - ``prompted_repair``
   * - ``modelscope``
     - Yes
     - No
     - Yes
     - Yes
     - No
     - ``provider_native``
   * - ``moonshot``
     - Yes
     - Yes
     - Yes
     - Yes
     - Yes
     - ``provider_native``
   * - ``ollama``
     - Yes
     - Yes
     - Yes
     - Yes
     - Yes
     - ``provider_native``
   * - ``openai``
     - Yes
     - Yes
     - Yes
     - Yes
     - Yes
     - ``provider_native``
   * - ``openrouter``
     - Yes
     - Yes
     - Yes
     - Yes
     - Yes
     - ``provider_native``
   * - ``zai``
     - Yes
     - Yes
     - Yes
     - Yes
     - Yes
     - ``provider_native``

